<?php
/**
 * The Header: Logo and main menu
 *
 * @package ECHO
 * @since ECHO 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js<?php
	// Class scheme_xxx need in the <html> as context for the <body>!
	echo ' scheme_' . esc_attr( echo_get_theme_option( 'color_scheme' ) );
?>">

<head>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	do_action( 'echo_action_before_body' );
	?>

	<div class="<?php echo esc_attr( apply_filters( 'echo_filter_body_wrap_class', 'body_wrap' ) ); ?>" <?php do_action('echo_action_body_wrap_attributes'); ?>>

		<?php do_action( 'echo_action_before_page_wrap' ); ?>

		<div class="<?php echo esc_attr( apply_filters( 'echo_filter_page_wrap_class', 'page_wrap' ) ); ?>" <?php do_action('echo_action_page_wrap_attributes'); ?>>

			<?php do_action( 'echo_action_page_wrap_start' ); ?>

			<?php
			$echo_full_post_loading = ( echo_is_singular( 'post' ) || echo_is_singular( 'attachment' ) ) && echo_get_value_gp( 'action' ) == 'full_post_loading';
			$echo_prev_post_loading = ( echo_is_singular( 'post' ) || echo_is_singular( 'attachment' ) ) && echo_get_value_gp( 'action' ) == 'prev_post_loading';

			// Don't display the header elements while actions 'full_post_loading' and 'prev_post_loading'
			if ( ! $echo_full_post_loading && ! $echo_prev_post_loading ) {

				// Short links to fast access to the content, sidebar and footer from the keyboard
				?>
				<a class="echo_skip_link skip_to_content_link" href="#content_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'echo_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to content", 'echo' ); ?></a>
				<?php if ( echo_sidebar_present() ) { ?>
				<a class="echo_skip_link skip_to_sidebar_link" href="#sidebar_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'echo_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to sidebar", 'echo' ); ?></a>
				<?php } ?>
				<a class="echo_skip_link skip_to_footer_link" href="#footer_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'echo_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to footer", 'echo' ); ?></a>

				<?php
				do_action( 'echo_action_before_header' );

				// Header
				$echo_header_type = echo_get_theme_option( 'header_type' );
				if ( 'custom' == $echo_header_type && ! echo_is_layouts_available() ) {
					$echo_header_type = 'default';
				}
				get_template_part( apply_filters( 'echo_filter_get_template_part', "templates/header-" . sanitize_file_name( $echo_header_type ) ) );

				// Side menu
				if ( in_array( echo_get_theme_option( 'menu_side' ), array( 'left', 'right' ) ) ) {
					get_template_part( apply_filters( 'echo_filter_get_template_part', 'templates/header-navi-side' ) );
				}

				// Mobile menu
				get_template_part( apply_filters( 'echo_filter_get_template_part', 'templates/header-navi-mobile' ) );

				do_action( 'echo_action_after_header' );

			}
			?>

			<?php do_action( 'echo_action_before_page_content_wrap' ); ?>

			<div class="page_content_wrap<?php
				if ( echo_is_off( echo_get_theme_option( 'remove_margins' ) ) ) {
					if ( empty( $echo_header_type ) ) {
						$echo_header_type = echo_get_theme_option( 'header_type' );
					}
					if ( 'custom' == $echo_header_type && echo_is_layouts_available() ) {
						$echo_header_id = echo_get_custom_header_id();
						if ( $echo_header_id > 0 ) {
							$echo_header_meta = echo_get_custom_layout_meta( $echo_header_id );
							if ( ! empty( $echo_header_meta['margin'] ) ) {
								?> page_content_wrap_custom_header_margin<?php
							}
						}
					}
					$echo_footer_type = echo_get_theme_option( 'footer_type' );
					if ( 'custom' == $echo_footer_type && echo_is_layouts_available() ) {
						$echo_footer_id = echo_get_custom_footer_id();
						if ( $echo_footer_id ) {
							$echo_footer_meta = echo_get_custom_layout_meta( $echo_footer_id );
							if ( ! empty( $echo_footer_meta['margin'] ) ) {
								?> page_content_wrap_custom_footer_margin<?php
							}
						}
					}
				}
				do_action( 'echo_action_page_content_wrap_class', $echo_prev_post_loading );
				?>"<?php
				if ( apply_filters( 'echo_filter_is_prev_post_loading', $echo_prev_post_loading ) ) {
					?> data-single-style="<?php echo esc_attr( echo_get_theme_option( 'single_style' ) ); ?>"<?php
				}
				do_action( 'echo_action_page_content_wrap_data', $echo_prev_post_loading );
			?>>
				<?php
				do_action( 'echo_action_page_content_wrap', $echo_full_post_loading || $echo_prev_post_loading );

				// Single posts banner
				if ( apply_filters( 'echo_filter_single_post_header', echo_is_singular( 'post' ) || echo_is_singular( 'attachment' ) ) ) {
					if ( $echo_prev_post_loading ) {
						if ( echo_get_theme_option( 'posts_navigation_scroll_which_block' ) != 'article' ) {
							do_action( 'echo_action_between_posts' );
						}
					}
					// Single post thumbnail and title
					$echo_path = apply_filters( 'echo_filter_get_template_part', 'templates/single-styles/' . echo_get_theme_option( 'single_style' ) );
					if ( echo_get_file_dir( $echo_path . '.php' ) != '' ) {
						get_template_part( $echo_path );
					}
				}

				// Widgets area above page
				$echo_body_style   = echo_get_theme_option( 'body_style' );
				$echo_widgets_name = echo_get_theme_option( 'widgets_above_page' );
				$echo_show_widgets = ! echo_is_off( $echo_widgets_name ) && is_active_sidebar( $echo_widgets_name );
				if ( $echo_show_widgets ) {
					if ( 'fullscreen' != $echo_body_style ) {
						?>
						<div class="content_wrap">
							<?php
					}
					echo_create_widgets_area( 'widgets_above_page' );
					if ( 'fullscreen' != $echo_body_style ) {
						?>
						</div>
						<?php
					}
				}

				// Content area
				do_action( 'echo_action_before_content_wrap' );
				?>
				<div class="content_wrap<?php echo 'fullscreen' == $echo_body_style ? '_fullscreen' : ''; ?>">

					<?php do_action( 'echo_action_content_wrap_start' ); ?>

					<div class="content">
						<?php
						do_action( 'echo_action_page_content_start' );

						// Skip link anchor to fast access to the content from keyboard
						?>
						<a id="content_skip_link_anchor" class="echo_skip_link_anchor" href="#"></a>
						<?php
						// Single posts banner between prev/next posts
						if ( ( echo_is_singular( 'post' ) || echo_is_singular( 'attachment' ) )
							&& $echo_prev_post_loading 
							&& echo_get_theme_option( 'posts_navigation_scroll_which_block' ) == 'article'
						) {
							do_action( 'echo_action_between_posts' );
						}

						// Widgets area above content
						echo_create_widgets_area( 'widgets_above_content' );

						do_action( 'echo_action_page_content_start_text' );
