<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package ECHO
 * @since ECHO 1.0
 */

$echo_template = apply_filters( 'echo_filter_get_template_part', echo_blog_archive_get_template() );

if ( ! empty( $echo_template ) && 'index' != $echo_template ) {

	get_template_part( $echo_template );

} else {

	echo_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$echo_stickies   = is_home()
								|| ( in_array( echo_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) echo_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$echo_post_type  = echo_get_theme_option( 'post_type' );
		$echo_args       = array(
								'blog_style'     => echo_get_theme_option( 'blog_style' ),
								'post_type'      => $echo_post_type,
								'taxonomy'       => echo_get_post_type_taxonomy( $echo_post_type ),
								'parent_cat'     => echo_get_theme_option( 'parent_cat' ),
								'posts_per_page' => echo_get_theme_option( 'posts_per_page' ),
								'sticky'         => echo_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $echo_stickies )
															&& count( $echo_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		echo_blog_archive_start();

		do_action( 'echo_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'echo_action_before_page_author' );
			get_template_part( apply_filters( 'echo_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'echo_action_after_page_author' );
		}

		if ( echo_get_theme_option( 'show_filters' ) ) {
			do_action( 'echo_action_before_page_filters' );
			echo_show_filters( $echo_args );
			do_action( 'echo_action_after_page_filters' );
		} else {
			do_action( 'echo_action_before_page_posts' );
			echo_show_posts( array_merge( $echo_args, array( 'cat' => $echo_args['parent_cat'] ) ) );
			do_action( 'echo_action_after_page_posts' );
		}

		do_action( 'echo_action_blog_archive_end' );

		echo_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'echo_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'echo_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
