<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package ECHO
 * @since ECHO 1.0
 */

if ( echo_sidebar_present() ) {
	
	$echo_sidebar_type = echo_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $echo_sidebar_type && ! echo_is_layouts_available() ) {
		$echo_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $echo_sidebar_type ) {
		// Default sidebar with widgets
		$echo_sidebar_name = echo_get_theme_option( 'sidebar_widgets' );
		echo_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $echo_sidebar_name ) ) {
			dynamic_sidebar( $echo_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$echo_sidebar_id = echo_get_custom_sidebar_id();
		do_action( 'echo_action_show_layout', $echo_sidebar_id );
	}
	$echo_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $echo_out ) ) {
		$echo_sidebar_position    = echo_get_theme_option( 'sidebar_position' );
		$echo_sidebar_position_ss = echo_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $echo_sidebar_position );
			echo ' sidebar_' . esc_attr( $echo_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $echo_sidebar_type );

			$echo_sidebar_scheme = apply_filters( 'echo_filter_sidebar_scheme', echo_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $echo_sidebar_scheme ) && ! echo_is_inherit( $echo_sidebar_scheme ) && 'custom' != $echo_sidebar_type ) {
				echo ' scheme_' . esc_attr( $echo_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="echo_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'echo_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $echo_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$echo_title = apply_filters( 'echo_filter_sidebar_control_title', 'float' == $echo_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'echo' ) : '' );
				$echo_text  = apply_filters( 'echo_filter_sidebar_control_text', 'above' == $echo_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'echo' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $echo_title ); ?>"><?php echo esc_html( $echo_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'echo_action_before_sidebar', 'sidebar' );
				echo_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $echo_out ) );
				do_action( 'echo_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'echo_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
