<?php
/**
 * Skin Setup
 *
 * @package ECHO
 * @since ECHO 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'echo_theme_defaults' ) ) {
	function echo_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 130,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0,
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( empty( $value ) && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'echo_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'echo_skin_setup', 1 );
	function echo_skin_setup() {

		$GLOBALS['ECHO_STORAGE'] = array_merge( $GLOBALS['ECHO_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-ancora',

			'theme_doc_url'       => '//echo.ancorathemes.com/doc',

			'theme_demofiles_url' => '//demofiles.ancorathemes.com/echo/',
			
			'theme_rate_url'      => '//themeforest.net/download',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

			'theme_download_url'  => '//themeforest.net/item/echo-digital-marketing-creative-agency-wordpress-theme/42884538',        // Ancora

			'theme_video_url'     => '//www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',   // Ancora

			'theme_privacy_url'   => '//ancorathemes.com/privacy-policy/',                   // Ancora

			'portfolio_url'       => '//themeforest.net/user/ancorathemes/portfolio',        // Ancora

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}


// Add/remove/change Theme Settings
if ( ! function_exists( 'echo_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'echo_skin_setup_settings', 1 );
	function echo_skin_setup_settings() {
		// Example: enable (true) / disable (false) thumbs in the prev/next navigation
		echo_storage_set_array( 'settings', 'thumbs_in_navigation', false );
		echo_storage_set_array2( 'required_plugins', 'instagram-feed', 'install', true);
	}
}



//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'echo_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'echo_skin_setup_fonts', 1 );
	function echo_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		echo_storage_set(
			'load_fonts', array(
				array(
					'name'   => 'DM Sans',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'ital,wght@0,400;0,500;0,700;1,400;1,500;1,700'
				),
				array(
					'name'   => 'termina',
					'family' => 'sans-serif',
					'link'   => 'https://use.typekit.net/zau2ogq.css',
					'styles' => ''
				),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		echo_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => basekit_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'echo' );

		echo_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'echo' ) ),
					'font-family'     => '"DM Sans",sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.647em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.65em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'echo' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '3.353rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.03em',
					'margin-top'      => '1.1em',
					'margin-bottom'   => '0.43em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '2.765rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.021em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.03em',
					'margin-top'      => '0.76em',
					'margin-bottom'   => '0.48em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '2.059rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.086em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.03em',
					'margin-top'      => '1.12em',
					'margin-bottom'   => '0.65em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '1.647rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.214em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.02em',
					'margin-top'      => '1.15em',
					'margin-bottom'   => '0.83em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '1.412rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.208em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.02em',
					'margin-top'      => '1.3em',
					'margin-bottom'   => '0.84em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '1.118rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.474em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.03em',
					'margin-top'      => '1.75em',
					'margin-bottom'   => '1.1em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '1.7rem',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '20px',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'echo' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '16px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'echo' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '14px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'echo' ) ),
					'font-family'     => 'termina,sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.03em',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'echo' ) ),
					'font-family'     => '"DM Sans",sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'echo' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'echo' ) ),
					'font-family'     => '"DM Sans",sans-serif',
				),
			)
		);

		// Font presets
		echo_storage_set(
			'font_presets', array(
				'karla' => array(
								'title'  => esc_html__( 'Karla', 'echo' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Dancing Script',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
													// Google font
													array(
														'name'   => 'Sansita Swashed',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Dancing Script",fantasy',
														'font-size'       => '1.25rem',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
														'font-size'       => '4em',
													),
													'h2'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h3'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h4'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h5'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h6'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'logo'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'button'  => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'submenu' => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
												),
							),
				'roboto' => array(
								'title'  => esc_html__( 'Roboto', 'echo' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Noto Sans JP',
														'family' => 'serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
													// Google font
													array(
														'name'   => 'Merriweather',
														'family' => 'sans-serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Noto Sans JP",serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
												),
							),
				'garamond' => array(
								'title'  => esc_html__( 'Garamond', 'echo' ),
								'load_fonts' => array(
													// Adobe font
													array(
														'name'   => 'Europe',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
													// Adobe font
													array(
														'name'   => 'Sofia Pro',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Sofia Pro",sans-serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Europe,sans-serif',
													),
												),
							),
			)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'echo_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'echo_skin_setup_schemes', 1 );
	function echo_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		echo_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'echo' ),
					'description' => esc_html__( 'Colors of the main content area', 'echo' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'echo' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'echo' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'echo' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'echo' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'echo' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'echo' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'echo' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'echo' ),
				),
			)
		);

		echo_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'echo' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'echo' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'echo' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'echo' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'echo' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'echo' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'echo' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'echo' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'echo' ),
					'description' => esc_html__( 'Color of the text inside this block', 'echo' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'echo' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'echo' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'echo' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'echo' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'echo' ),
					'description' => esc_html__( 'Color of the links inside this block', 'echo' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'echo' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'echo' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'echo' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'echo' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'echo' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'echo' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'echo' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'echo' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'echo' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'echo' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F3EF', // ok +
					'bd_color'         => '#D6D3CE', // ok +

					// Text and links colors
					'text'             => '#65645F', // ok +
					'text_light'       => '#807F7C', // ok +
					'text_dark'        => '#1E1A1F', // ok +
					'text_link'        => '#F27044', // ok
					'text_hover'       => '#E05F34', // ok
					'text_link2'       => '#FCB800', // ok
					'text_hover2'      => '#DEA200', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff', //
					'alter_bg_hover'   => '#F9F9F9', //
					'alter_bd_color'   => '#D6D3CE', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#807F7C', // ok +
					'alter_dark'       => '#1E1A1F', // ok +
					'alter_link'       => '#F27044', // ok
					'alter_hover'      => '#E05F34', //
					'alter_link2'      => '#FCB800', // ok
					'alter_hover2'     => '#DEA200', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#F27044', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D6D3CE', // ok +
					'input_bd_hover'   => '#1E1A1F', // ok +
					'input_text'       => '#807F7C', // ok +
					'input_light'      => '#807F7C', // ok +
					'input_dark'       => '#1E1A1F', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#100E10', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#100E10', // ok +
					'bd_color'         => '#383838', // ok +

					// Text and links colors
					'text'             => '#727272', // ok +
					'text_light'       => '#5B595C', // ok +
					'text_dark'        => '#FFFFFF', // ok
					'text_link'        => '#F27044', // ok
					'text_hover'       => '#E05F34', // ok
					'text_link2'       => '#FCB800', // ok
					'text_hover2'      => '#DEA200', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#1E1A1F', // ok +
					'alter_bg_hover'   => '#2C313D', //
					'alter_bd_color'   => '#383838', // ok +
					'alter_bd_hover'   => '#53535C', // 
					'alter_text'       => '#727272', // ok +
					'alter_light'      => '#5B595C', // ok +
					'alter_dark'       => '#FFFFFF', // ok
					'alter_link'       => '#F27044', // ok
					'alter_hover'      => '#E05F34', // ok
					'alter_link2'      => '#FCB800', // ok
					'alter_hover2'     => '#DEA200', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#727272', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#F27044', // ok
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#3c3d51', // ok
					'input_bd_hover'   => '#ffffff', // ok
					'input_text'       => '#727272', // ok +
					'input_light'      => '#727272', // ok +
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FFFFFF', // ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#1E1A1F', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#1E1A1F', // ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'light'
			'light' => array(
				'title'    => esc_html__( 'Light', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff', //
					'bd_color'         => '#D6D3CE', // ok +

					// Text and links colors
					'text'             => '#65645F', // ok +
					'text_light'       => '#807F7C', // ok +
					'text_dark'        => '#1E1A1F', // ok +
					'text_link'        => '#F27044', // ok
					'text_hover'       => '#E05F34', // ok
					'text_link2'       => '#FCB800', // ok
					'text_hover2'      => '#DEA200', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F5F3EF', // ok +
					'alter_bg_hover'   => '#ffffff', //
					'alter_bd_color'   => '#D6D3CE', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#807F7C', // ok +
					'alter_dark'       => '#1E1A1F', // ok +
					'alter_link'       => '#F27044', // ok
					'alter_hover'      => '#E05F34', // ok
					'alter_link2'      => '#FCB800', // ok
					'alter_hover2'     => '#DEA200', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#F27044', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D6D3CE', // ok +
					'input_bd_hover'   => '#1E1A1F', // ok +
					'input_text'       => '#807F7C', // ok +
					'input_light'      => '#807F7C', // ok +
					'input_dark'       => '#1E1A1F', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#1E1A1F', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'creative default'
			'creative_default' => array(
				'title'    => esc_html__( 'Creative default', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FEFFF2', // ok +
					'bd_color'         => '#CFD0C6', // ok +

					// Text and links colors
					'text'             => '#65645F', // ok +
					'text_light'       => '#807F7C', // ok +
					'text_dark'        => '#1E1A1F', // ok +
					'text_link'        => '#EA8BA0', // ok
					'text_hover'       => '#E07E94', // ok
					'text_link2'       => '#491955', // ok
					'text_hover2'      => '#35113E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F2F2EB', //
					'alter_bg_hover'   => '#F9F9F9', //
					'alter_bd_color'   => '#CFD0C6', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#807F7C', // ok +
					'alter_dark'       => '#1E1A1F', // ok +
					'alter_link'       => '#EA8BA0', // ok
					'alter_hover'      => '#E07E94', //
					'alter_link2'      => '#491955', // ok
					'alter_hover2'     => '#35113E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#EA8BA0', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#CFD0C6', // ok +
					'input_bd_hover'   => '#1E1A1F', // ok +
					'input_text'       => '#807F7C', // ok +
					'input_light'      => '#807F7C', // ok +
					'input_dark'       => '#1E1A1F', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#161417', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'creative dark'
			'creative_dark'    => array(
				'title'    => esc_html__( 'Creative dark', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#161417', // ok +
					'bd_color'         => '#383838', // ok +

					// Text and links colors
					'text'             => '#727272', // ok +
					'text_light'       => '#5B595C', // ok +
					'text_dark'        => '#FFFFFF', // ok
					'text_link'        => '#EA8BA0', // ok
					'text_hover'       => '#E07E94', // ok
					'text_link2'       => '#491955', // ok
					'text_hover2'      => '#35113E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#1E1A1F', // ok +
					'alter_bg_hover'   => '#2C313D', //
					'alter_bd_color'   => '#383838', // ok +
					'alter_bd_hover'   => '#53535C', // 
					'alter_text'       => '#727272', // ok +
					'alter_light'      => '#5B595C', // ok +
					'alter_dark'       => '#FFFFFF', // ok
					'alter_link'       => '#EA8BA0', // ok
					'alter_hover'      => '#E07E94', // ok
					'alter_link2'      => '#491955', // ok
					'alter_hover2'     => '#35113E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#727272', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#EA8BA0', // ok
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#3c3d51', // ok
					'input_bd_hover'   => '#ffffff', // ok
					'input_text'       => '#727272', // ok +
					'input_light'      => '#727272', // ok +
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FFFFFF', // ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#1E1A1F', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#1E1A1F', // ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'creative light'
			'creative_light' => array(
				'title'    => esc_html__( 'Creative light', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F2F2EB', //
					'bd_color'         => '#CFD0C6', // ok +

					// Text and links colors
					'text'             => '#65645F', // ok +
					'text_light'       => '#807F7C', // ok +
					'text_dark'        => '#1E1A1F', // ok +
					'text_link'        => '#EA8BA0', // ok
					'text_hover'       => '#E07E94', // ok
					'text_link2'       => '#491955', // ok
					'text_hover2'      => '#35113E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FEFFF2', // ok +
					'alter_bg_hover'   => '#ffffff', //
					'alter_bd_color'   => '#CFD0C6', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#807F7C', // ok +
					'alter_dark'       => '#1E1A1F', // ok +
					'alter_link'       => '#EA8BA0', // ok
					'alter_hover'      => '#E07E94', // ok
					'alter_link2'      => '#491955', // ok
					'alter_hover2'     => '#35113E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1E1A1F', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#EA8BA0', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#CFD0C6', // ok +
					'input_bd_hover'   => '#1E1A1F', // ok +
					'input_text'       => '#807F7C', // ok +
					'input_light'      => '#807F7C', // ok +
					'input_dark'       => '#1E1A1F', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#1E1A1F', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'project default'
			'project_default' => array(
				'title'    => esc_html__( 'Project default', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F4F8FA', // ok +
					'bd_color'         => '#D1D9DD', // ok +

					// Text and links colors
					'text'             => '#636376', // ok +
					'text_light'       => '#898C9A', // ok +
					'text_dark'        => '#181D4E', // ok +
					'text_link'        => '#0033DD', // ok
					'text_hover'       => '#0026A5', // ok
					'text_link2'       => '#A50CC1', // ok
					'text_hover2'      => '#78018E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF', //
					'alter_bg_hover'   => '#F9F9F9', //
					'alter_bd_color'   => '#D1D9DD', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#898C9A', // ok +
					'alter_dark'       => '#181D4E', // ok +
					'alter_link'       => '#0033DD', // ok
					'alter_hover'      => '#0026A5', //
					'alter_link2'      => '#A50CC1', // ok
					'alter_hover2'     => '#78018E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#181D4E', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#0033DD', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D1D9DD', // ok +
					'input_bd_hover'   => '#181D4E', // ok +
					'input_text'       => '#898C9A', // ok +
					'input_light'      => '#898C9A', // ok +
					'input_dark'       => '#181D4E', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#161417', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'project dark'
			'project_dark'    => array(
				'title'    => esc_html__( 'Project dark', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#060713', // ok +
					'bd_color'         => '#353643', // ok +

					// Text and links colors
					'text'             => '#A3A7AD', // ok +
					'text_light'       => '#A3A7AD', // ok +
					'text_dark'        => '#F4F8FA', // ok
					'text_link'        => '#0033DD', // ok
					'text_hover'       => '#0026A5', // ok
					'text_link2'       => '#A50CC1', // ok
					'text_hover2'      => '#78018E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#141627', // ok +
					'alter_bg_hover'   => '#2C313D', //
					'alter_bd_color'   => '#353643', // ok +
					'alter_bd_hover'   => '#53535C', // 
					'alter_text'       => '#A3A7AD', // ok +
					'alter_light'      => '#A3A7AD', // ok +
					'alter_dark'       => '#F4F8FA', // ok
					'alter_link'       => '#0033DD', // ok
					'alter_hover'      => '#0026A5', // ok
					'alter_link2'      => '#A50CC1', // ok
					'alter_hover2'     => '#78018E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#181D4E', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A3A7AD', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#0033DD', // ok
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#3c3d51', // ok
					'input_bd_hover'   => '#ffffff', // ok
					'input_text'       => '#A3A7AD', // ok +
					'input_light'      => '#A3A7AD', // ok +
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F4F8FA', // ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#181D4E', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#181D4E', // ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'project light'
			'project_light' => array(
				'title'    => esc_html__( 'Project light', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFFFFF', //
					'bd_color'         => '#D1D9DD', // ok +

					// Text and links colors
					'text'             => '#636376', // ok +
					'text_light'       => '#898C9A', // ok +
					'text_dark'        => '#181D4E', // ok +
					'text_link'        => '#0033DD', // ok
					'text_hover'       => '#0026A5', // ok
					'text_link2'       => '#A50CC1', // ok
					'text_hover2'      => '#78018E', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F4F8FA', // ok +
					'alter_bg_hover'   => '#ffffff', //
					'alter_bd_color'   => '#D1D9DD', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#898C9A', // ok +
					'alter_dark'       => '#181D4E', // ok +
					'alter_link'       => '#0033DD', // ok
					'alter_hover'      => '#0026A5', // ok
					'alter_link2'      => '#A50CC1', // ok
					'alter_hover2'     => '#78018E', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#181D4E', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#0033DD', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D1D9DD', // ok +
					'input_bd_hover'   => '#181D4E', // ok +
					'input_text'       => '#898C9A', // ok +
					'input_light'      => '#898C9A', // ok +
					'input_dark'       => '#181D4E', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#181D4E', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'bright default'
			'bright_default' => array(
				'title'    => esc_html__( 'Bright default', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F4F8FA', // ok +
					'bd_color'         => '#D1D9DD', // ok +

					// Text and links colors
					'text'             => '#636376', // ok +
					'text_light'       => '#898C9A', // ok +
					'text_dark'        => '#070814', // ok +
					'text_link'        => '#EFC421', // ok
					'text_hover'       => '#E6B100', // ok
					'text_link2'       => '#DB2D25', // ok
					'text_hover2'      => '#CC170F', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF', //
					'alter_bg_hover'   => '#F9F9F9', //
					'alter_bd_color'   => '#D1D9DD', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#898C9A', // ok +
					'alter_dark'       => '#070814', // ok +
					'alter_link'       => '#EFC421', // ok
					'alter_hover'      => '#E6B100', //
					'alter_link2'      => '#DB2D25', // ok
					'alter_hover2'     => '#CC170F', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#070814', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#EFC421', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D1D9DD', // ok +
					'input_bd_hover'   => '#070814', // ok +
					'input_text'       => '#898C9A', // ok +
					'input_light'      => '#898C9A', // ok +
					'input_dark'       => '#070814', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#161417', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'bright dark'
			'bright_dark'    => array(
				'title'    => esc_html__( 'Bright dark', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#04050C', // ok +
					'bd_color'         => '#313238', // ok +

					// Text and links colors
					'text'             => '#9AA2AF', // ok +
					'text_light'       => '#A3A7AD', // ok +
					'text_dark'        => '#F4F8FA', // ok
					'text_link'        => '#EFC421', // ok
					'text_hover'       => '#E6B100', // ok
					'text_link2'       => '#DB2D25', // ok
					'text_hover2'      => '#CC170F', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#070814', // ok +
					'alter_bg_hover'   => '#2C313D', //
					'alter_bd_color'   => '#313238', // ok +
					'alter_bd_hover'   => '#53535C', // 
					'alter_text'       => '#9AA2AF', // ok +
					'alter_light'      => '#A3A7AD', // ok +
					'alter_dark'       => '#F4F8FA', // ok
					'alter_link'       => '#EFC421', // ok
					'alter_hover'      => '#E6B100', // ok
					'alter_link2'      => '#DB2D25', // ok
					'alter_hover2'     => '#CC170F', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#070814', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9AA2AF', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#EFC421', // ok
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#3c3d51', // ok
					'input_bd_hover'   => '#ffffff', // ok
					'input_text'       => '#9AA2AF', // ok +
					'input_light'      => '#9AA2AF', // ok +
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F4F8FA', // ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#070814', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#070814', // ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'bright light'
			'bright_light' => array(
				'title'    => esc_html__( 'Bright light', 'echo' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FFFFFF', //
					'bd_color'         => '#D1D9DD', // ok +

					// Text and links colors
					'text'             => '#636376', // ok +
					'text_light'       => '#898C9A', // ok +
					'text_dark'        => '#070814', // ok +
					'text_link'        => '#EFC421', // ok
					'text_hover'       => '#E6B100', // ok
					'text_link2'       => '#DB2D25', // ok
					'text_hover2'      => '#CC170F', // ok
					'text_link3'       => '#DEA200', // ok
					'text_hover3'      => '#AC9849', // ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F4F8FA', // ok +
					'alter_bg_hover'   => '#ffffff', //
					'alter_bd_color'   => '#D1D9DD', // ok +
					'alter_bd_hover'   => '#E0DCD4', //
					'alter_text'       => '#797C7F', //
					'alter_light'      => '#898C9A', // ok +
					'alter_dark'       => '#070814', // ok +
					'alter_link'       => '#EFC421', // ok
					'alter_hover'      => '#E6B100', // ok
					'alter_link2'      => '#DB2D25', // ok
					'alter_hover2'     => '#CC170F', // ok
					'alter_link3'      => '#DEA200', // ok
					'alter_hover3'     => '#AC9849', // ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#070814', // ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#D2D8E2', // ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //
					'extra_link'       => '#EFC421', // ok
					'extra_hover'      => '#ffffff', //
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //
					'input_bg_hover'   => 'transparent', //
					'input_bd_color'   => '#D1D9DD', // ok +
					'input_bd_hover'   => '#070814', // ok +
					'input_text'       => '#898C9A', // ok +
					'input_light'      => '#898C9A', // ok +
					'input_dark'       => '#070814', // ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#070814', // ok +
					'inverse_link'     => '#ffffff', //
					'inverse_hover'    => '#ffffff', //

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			), 
		);
		echo_storage_set( 'schemes', $schemes );
		echo_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> echo_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'echo' ),
		//---> 	'description' => __( 'Description of the new color 1', 'echo' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		echo_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
                'alter_dark_015'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.15,
                ),
                'alter_dark_02'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.2,
                ),
                'alter_dark_05'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.5,
                ),
                'alter_dark_08'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.8,
                ),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
                'text_dark_003'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.03,
                ),
                'text_dark_005'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.05,
                ),
                'text_dark_008'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.08,
                ),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
                'text_dark_03'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.3,
                ),
                'text_dark_05'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.5,
                ),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'text_dark_08'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.8,
                ),
                'text_link_007'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.07,
                ),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
                'text_link_03'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.3,
                ),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link2_08'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.8,
                ),
                'text_link2_007'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.07,
                ),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
                'text_link2_03'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.3,
                ),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
                'text_link3_007'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.07,
                ),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
                'text_link3_03'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.3,
                ),
                'inverse_text_03'      => array(
                    'color' => 'inverse_text',
                    'alpha' => 0.3,
                ),
                'inverse_link_08'      => array(
                    'color' => 'inverse_link',
                    'alpha' => 0.8,
                ),
                'inverse_hover_08'      => array(
                    'color' => 'inverse_hover',
                    'alpha' => 0.8,
                ),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 4,
					'saturation' => -10,
					'brightness' => 10,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		echo_storage_set(
			'schemes_simple', array(
				'text_link'        => array(),
				'text_hover'       => array(),
				'text_link2'       => array(),
				'text_hover2'      => array(),
				'text_link3'       => array(),
				'text_hover3'      => array(),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
			)
		);

		// Parameters to set order of schemes in the css
		echo_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		echo_storage_set(
			'color_presets', array(
				'autumn' => array(
								'title'  => esc_html__( 'Autumn', 'echo' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	),
												'dark' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	)
												)
							),
				'green' => array(
								'title'  => esc_html__( 'Natural Green', 'echo' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	),
												'dark' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	)
												)
							),
			)
		);
	}
}
// Enqueue clone specific style
if ( ! function_exists( 'echo_clone_frontend_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'echo_clone_frontend_scripts', 2150 );
	function echo_clone_frontend_scripts() {
		$echo_url = echo_get_file_url( echo_skins_get_current_skin_dir() . 'extra-styles.css' );
		if ( '' != $echo_url ) {
			wp_enqueue_style( 'echo-extra-styles-' . esc_attr( echo_skins_get_current_skin_name() ), $echo_url, array(), null );
		}
	}
}
//Add new option
if ( ! function_exists( 'echo_skin_add_page_grained_texture' ) ) {
    add_filter( 'after_setup_theme', 'echo_skin_add_page_grained_texture', 3 );
    function echo_skin_add_page_grained_texture() {
		echo_storage_set_array_after(
			'options', 'remove_margins', array_merge(
				array(
					'extra_bg_image' => array(
						"title" => esc_html__('Extra background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload background-image to display it in the page. Does not work for boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 0 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'multi_extra_bg_image' => array(
						'title'    => esc_html__( 'Use multiplе background images', 'echo' ),
						'desc'     => wp_kses_data( __( 'You can choose several images for the background. Attention! This is a decorative option that requires specific images.', 'echo' ) ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
						),
						'refresh'  => false,
						'std'      => 0,
						'pro_only'   => ECHO_THEME_FREE,
						'type'     => 'switch',
					)
				),
				array(
					'disable_multi_extra_bg_image_tablet' => array(
						'title'    => esc_html__( 'Disable multiplе background images on tablet', 'echo' ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 1 )
						),
						'refresh'  => false,
						'std'      => 0,
						'pro_only'   => ECHO_THEME_FREE,
						'type'     => 'switch',
					)
				),
				array(
					'disable_multi_extra_bg_image_mobile' => array(
						'title'    => esc_html__( 'Disable multiplе background images on mobile', 'echo' ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 1 )
						),
						'refresh'  => false,
						'std'      => 0,
						'pro_only'   => ECHO_THEME_FREE,
						'type'     => 'switch',
					)
				),
				array(
					'extra_bg_image_top' => array(
						"title" => esc_html__('Top background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload a background image to be displayed on the page. Does not work with a boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 1 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'extra_bg_image_bottom' => array(
						"title" => esc_html__('Bottom background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload a background image to be displayed on the page. Does not work with a boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 1 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'more_multi_extra_bg_image' => array(
						'title'    => esc_html__( 'Enable additional background images for long pages', 'echo' ),
						'desc'     => wp_kses_data( __( 'Attention! You can choose several images for the background. If you use this option, you have to use all three imagepickers. This is a decorative option that requires specific images.', 'echo' ) ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'multi_extra_bg_image' => array( 1 )
						),
						'refresh'  => false,
						'std'      => 0,
						'pro_only'   => ECHO_THEME_FREE,
						'type'     => 'switch',
					)
				),
				array(
					'extra_bg_image_medium_one' => array(
						"title" => esc_html__('Middle background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload a background image to be displayed on the page. Does not work with a boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'more_multi_extra_bg_image' => array( 1 ),
							'multi_extra_bg_image' => array( 1 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'extra_bg_image_medium_two' => array(
						"title" => esc_html__('Right background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload a background image to be displayed on the page. Does not work with a boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'more_multi_extra_bg_image' => array( 1 ),
							'multi_extra_bg_image' => array( 1 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'extra_bg_image_medium_three' => array(
						"title" => esc_html__('Left background image', 'echo'),
						"desc" => wp_kses_data( __('Select or upload a background image to be displayed on the page. Does not work with a boxed body style.', 'echo') ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'dependency' => array(
							'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
							'more_multi_extra_bg_image' => array( 1 ),
							'multi_extra_bg_image' => array( 1 )
						),
						"std" => '',
						'pro_only'   => ECHO_THEME_FREE,
						"type" => "image"
					),
				),
				array(
					'grained_switch' => array(
						'title'    => esc_html__( 'Grained textures', 'echo' ),
						'desc'     => wp_kses_data( __( 'Activate grained textures', 'echo' ) ),
						"override" => array(
							'mode' => 'page',
							'section' => esc_html__('Content', 'echo')
						),
						'refresh'  => false,
						'std'      => 0,
						'pro_only'   => ECHO_THEME_FREE,
						'type'     => 'switch',
					)
				)
			)
		);
    }
}
if ( ! function_exists( 'echo_skin_filter_page_wrap_class' ) ) {
    add_action('echo_filter_page_wrap_class', 'echo_skin_filter_page_wrap_class');
    function echo_skin_filter_page_wrap_class($class) {
        $disable_multi_extra_bg_image_tablet = echo_get_theme_option('disable_multi_extra_bg_image_tablet');
        $disable_multi_extra_bg_image_mobile = echo_get_theme_option('disable_multi_extra_bg_image_mobile');
        $multi_extra_bg_image = echo_get_theme_option('multi_extra_bg_image');
        $more_multi_extra_bg_image = echo_get_theme_option('more_multi_extra_bg_image');
        $extra_bg_image = echo_get_theme_option('extra_bg_image');
        $extra_bg_image_top = echo_get_theme_option('extra_bg_image_top');
        $extra_bg_image_bottom = echo_get_theme_option('extra_bg_image_bottom');
        $extra_bg_image_medium_one = echo_get_theme_option('extra_bg_image_medium_one');
        $extra_bg_image_medium_two = echo_get_theme_option('extra_bg_image_medium_two');
        $extra_bg_image_medium_three = echo_get_theme_option('extra_bg_image_medium_three');
        $body_boxed_style = echo_get_theme_option( 'body_style' ) == 'boxed';
		if( !$multi_extra_bg_image ) {
			if (!empty( $extra_bg_image ) && !$body_boxed_style ) {
				$custom_bg = ' ' . 'with_bg' . ' ' . echo_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image) . ');');
				$class = $class . $custom_bg;
			}
		} else {
			if (!empty( $extra_bg_image_top ) && empty( $extra_bg_image_bottom ) && !$body_boxed_style && !$more_multi_extra_bg_image ) {
				$custom_bg = ' ' . 'with_bg_top' . ' ' . echo_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image_top) . ');');
				$class = $class . $custom_bg;
			} elseif (!empty( $extra_bg_image_top ) && !empty( $extra_bg_image_bottom ) && !$body_boxed_style && !$more_multi_extra_bg_image ) {
				$custom_bg = ' ' . 'with_bg_top_bottom' . ' ' . echo_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image_top) . '), 
				url(' . esc_url($extra_bg_image_bottom) . ');');
				$class = $class . $custom_bg;
			} else {
				$custom_bg = ' ' . 'with_bg_all' . ' ' . echo_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image_top) . '), 
				url(' . esc_url($extra_bg_image_medium_one) . '), 
				url(' . esc_url($extra_bg_image_medium_two) . '), 
				url(' . esc_url($extra_bg_image_medium_three) . '), 
				url(' . esc_url($extra_bg_image_bottom) . ');');
				$class = $class . $custom_bg;
			}
			if (!empty( $extra_bg_image_top ) && !$body_boxed_style && $disable_multi_extra_bg_image_tablet ) {
				$custom_bg = ' ' . 'with_bg_disable_tablet';
				$class = $class . $custom_bg;
			}
			if (!empty( $extra_bg_image_top ) && !$body_boxed_style && $disable_multi_extra_bg_image_mobile ) {
				$custom_bg = ' ' . 'with_bg_disable_mobile';
				$class = $class . $custom_bg;
			}
		}
        return $class;
    }
}

// Add div with fixed background
if ( ! function_exists( 'echo_skin_action_before_page_wrap' ) ) {
    add_action('echo_action_before_page_wrap', 'echo_skin_action_before_page_wrap');
    function echo_skin_action_before_page_wrap()  {

        $grained_switch_on = echo_is_on( echo_get_theme_option( 'grained_switch' ) );
        $grained = ($grained_switch_on) ? 'grained_effect' : '';
        $grained_wrap = '<div class="'. $grained .'" >' .'</div>';

        if  ( $grained_switch_on ) {
            echo_show_layout($grained_wrap );
        }
    }
}

// Add theme specified classes to the body
if ( ! function_exists( 'echo_skin_add_body_classes' ) ) {
    add_filter( 'body_class', 'echo_skin_add_body_classes' );
    function echo_skin_add_body_classes($classes) {
        if ( echo_is_on( echo_get_theme_option( 'grained_switch' )  ) ) {
            $classes[] = 'grained_bg';
        }
        return $classes;
    }
}
// Custom styles
$echo_clone_style_path = echo_get_file_dir( echo_skins_get_current_skin_dir() . 'extra-styles.php' );
if ( ! empty( $echo_clone_style_path ) ) {
	require_once $echo_clone_style_path;
}
// Activation methods
if ( ! function_exists( 'echo_skin_filter_activation_methods' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'echo_skin_filter_activation_methods', 10, 1 );
    function echo_skin_filter_activation_methods( $args ) {
        $args['elements_key'] = true;
        return $args;
    }
}
