<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package ECHO
 * @since ECHO 1.0
 */

$echo_template_args = get_query_var( 'echo_template_args' );

if ( is_array( $echo_template_args ) ) {
	$echo_columns    = empty( $echo_template_args['columns'] ) ? 2 : max( 1, $echo_template_args['columns'] );
	$echo_blog_style = array( $echo_template_args['type'], $echo_columns );
    $echo_columns_class = echo_get_column_class( 1, $echo_columns, ! empty( $echo_template_args['columns_tablet']) ? $echo_template_args['columns_tablet'] : '', ! empty($echo_template_args['columns_mobile']) ? $echo_template_args['columns_mobile'] : '' );
} else {
	$echo_template_args = array();
	$echo_blog_style = explode( '_', echo_get_theme_option( 'blog_style' ) );
	$echo_columns    = empty( $echo_blog_style[1] ) ? 2 : max( 1, $echo_blog_style[1] );
    $echo_columns_class = echo_get_column_class( 1, $echo_columns );
}
$echo_expanded   = ! echo_sidebar_present() && echo_get_theme_option( 'expand_content' ) == 'expand';

$echo_post_format = get_post_format();
$echo_post_format = empty( $echo_post_format ) ? 'standard' : str_replace( 'post-format-', '', $echo_post_format );

?><div class="<?php
	if ( ! empty( $echo_template_args['slider'] ) ) {
		echo ' slider-slide swiper-slide';
	} else {
		echo ( echo_is_blog_style_use_masonry( $echo_blog_style[0] ) ? 'masonry_item masonry_item-1_' . esc_attr( $echo_columns ) : esc_attr( $echo_columns_class ) );
	}
?>"><article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
		'post_item post_item_container post_format_' . esc_attr( $echo_post_format )
				. ' post_layout_classic post_layout_classic_' . esc_attr( $echo_columns )
				. ' post_layout_' . esc_attr( $echo_blog_style[0] )
				. ' post_layout_' . esc_attr( $echo_blog_style[0] ) . '_' . esc_attr( $echo_columns )
	);
	echo_add_blog_animation( $echo_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$echo_hover      = ! empty( $echo_template_args['hover'] ) && ! echo_is_inherit( $echo_template_args['hover'] )
							? $echo_template_args['hover']
							: echo_get_theme_option( 'image_hover' );

	$echo_components = ! empty( $echo_template_args['meta_parts'] )
							? ( is_array( $echo_template_args['meta_parts'] )
								? $echo_template_args['meta_parts']
								: explode( ',', $echo_template_args['meta_parts'] )
								)
							: echo_array_get_keys_by_value( echo_get_theme_option( 'meta_parts' ) );

	echo_show_post_featured( apply_filters( 'echo_filter_args_featured',
		array(
			'thumb_size' => ! empty( $echo_template_args['thumb_size'] )
				? $echo_template_args['thumb_size']
				: echo_get_thumb_size(
					'classic' == $echo_blog_style[0]
						? ( strpos( echo_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $echo_columns > 2 ? 'big' : 'huge' )
								: ( $echo_columns > 2
									? ( $echo_expanded ? 'square' : 'square' )
									: ($echo_columns > 1 ? 'square' : ( $echo_expanded ? 'huge' : 'big' ))
									)
							)
						: ( strpos( echo_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $echo_columns > 2 ? 'masonry-big' : 'full' )
								: ($echo_columns === 1 ? ( $echo_expanded ? 'huge' : 'big' ) : ( $echo_columns <= 2 && $echo_expanded ? 'masonry-big' : 'masonry' ))
							)
			),
			'hover'      => $echo_hover,
			'meta_parts' => $echo_components,
			'no_links'   => ! empty( $echo_template_args['no_links'] ),
        ),
        'content-classic',
        $echo_template_args
    ) );

	// Title and post meta
	$echo_show_title = get_the_title() != '';
	$echo_show_meta  = count( $echo_components ) > 0 && ! in_array( $echo_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $echo_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php

			// Post meta
			if ( apply_filters( 'echo_filter_show_blog_meta', $echo_show_meta, $echo_components, 'classic' ) ) {
				if ( count( $echo_components ) > 0 ) {
					do_action( 'echo_action_before_post_meta' );
					echo_show_post_meta(
						apply_filters(
							'echo_filter_post_meta_args', array(
							'components' => join( ',', $echo_components ),
							'seo'        => false,
							'echo'       => true,
						), $echo_blog_style[0], $echo_columns
						)
					);
					do_action( 'echo_action_after_post_meta' );
				}
			}

			// Post title
			if ( apply_filters( 'echo_filter_show_blog_title', true, 'classic' ) ) {
				do_action( 'echo_action_before_post_title' );
				if ( empty( $echo_template_args['no_links'] ) ) {
					the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
				} else {
					the_title( '<h4 class="post_title entry-title">', '</h4>' );
				}
				do_action( 'echo_action_after_post_title' );
			}

			if( !in_array( $echo_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
				// More button
				if ( apply_filters( 'echo_filter_show_blog_readmore', ! $echo_show_title || ! empty( $echo_template_args['more_button'] ), 'classic' ) ) {
					if ( empty( $echo_template_args['no_links'] ) ) {
						do_action( 'echo_action_before_post_readmore' );
						echo_show_post_more_link( $echo_template_args, '<div class="more-wrap">', '</div>' );
						do_action( 'echo_action_after_post_readmore' );
					}
				}
			}
			?>
		</div><!-- .entry-header -->
		<?php
	}

	// Post content
	if( in_array( $echo_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
		ob_start();
		if (apply_filters('echo_filter_show_blog_excerpt', empty($echo_template_args['hide_excerpt']) && echo_get_theme_option('excerpt_length') > 0, 'classic')) {
			echo_show_post_content($echo_template_args, '<div class="post_content_inner">', '</div>');
		}
		// More button
		if(! empty( $echo_template_args['more_button'] )) {
			if ( empty( $echo_template_args['no_links'] ) ) {
				do_action( 'echo_action_before_post_readmore' );
				echo_show_post_more_link( $echo_template_args, '<div class="more-wrap">', '</div>' );
				do_action( 'echo_action_after_post_readmore' );
			}
		}
		$echo_content = ob_get_contents();
		ob_end_clean();
		echo_show_layout($echo_content, '<div class="post_content entry-content">', '</div><!-- .entry-content -->');
	}
	?>

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
